summaryrefslogtreecommitdiffstats
path: root/korn/kio_count.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korn/kio_count.cpp')
-rw-r--r--korn/kio_count.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/korn/kio_count.cpp b/korn/kio_count.cpp
index d97fa1e9..71da3080 100644
--- a/korn/kio_count.cpp
+++ b/korn/kio_count.cpp
@@ -259,7 +259,7 @@ void KIO_Count::entries( KIO::Job* job, const KIO::UDSEntryList &list )
for ( it1 = list.begin() ; it1 != list.end() ; it1++ )
{
/*
* The list contains multiple objects. Each object could be a file.
* Settings about it are saved in this scope until it is added to the list.
*/
isFile=false;
@@ -292,7 +292,7 @@ void KIO_Count::entries( KIO::Job* job, const KIO::UDSEntryList &list )
if( ! fileinfo.name.isNull() && isFile )
{
_new_mailurls->append( fileinfo );
- if( ! old_list.contains( fileinfo.name ) && _kio->passivePopup() )
+ if( ! old_list.tqcontains( fileinfo.name ) && _kio->passivePopup() )
showPassive( fileinfo.name );
}
}
@@ -259,7 +259,7 @@ void KIO_Count::entries( KIO::Job* job, const KIO::UDSEntryList &list )
{
/*
- * The list contains multiple objects. Each object could be a file.
+ * The list tqcontains multiple objects. Each object could be a file.
* Settings about it are saved in this scope until it is added to the list.
*/